==> i2p_0.8.11%2Brepack.orig.tar.bz2: i2p-0.8.11/core/java/src/net/metanotion/io/data/IntBytes.java <==
/*
Copyright (c) 2006, Matthew Estes
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

	* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
	* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
	* Neither the name of Metanotion Software nor the names of its
contributors may be used to endorse or promote products derived from this
software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package net.metanotion.io.data;

import net.metanotion.io.Serializer;

public class IntBytes implements Serializer {
	public byte[] getBytes(Object o) {
		byte[] b = new byte[4];
		int v = ((Integer) o).intValue();
 		b[0] = (byte)(0xff & (v >> 24));
 		b[1] = (byte)(0xff & (v >> 16));
		b[2] = (byte)(0xff & (v >>  8));
 		b[3] = (byte)(0xff & v);
 		return b;
	}

	public Object construct(byte[] b) {
		int v = (((int)(b[0] & 0xff) << 24) |
				 ((int)(b[1] & 0xff) << 16) |
				 ((int)(b[2] & 0xff) <<  8) |
				 ((int)(b[3] & 0xff)));
		return new Integer(v);
	}
}

==> i2p_0.9.3%2Brepack.orig.tar.bz2: i2p-0.9.3/core/java/src/net/metanotion/io/data/IntBytes.java <==
/*
Copyright (c) 2006, Matthew Estes
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

	* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
	* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
	* Neither the name of Metanotion Software nor the names of its
contributors may be used to endorse or promote products derived from this
software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package net.metanotion.io.data;

import net.metanotion.io.Serializer;

public class IntBytes implements Serializer {
	public byte[] getBytes(Object o) {
		byte[] b = new byte[4];
		int v = ((Integer) o).intValue();
 		b[0] = (byte)(0xff & (v >> 24));
 		b[1] = (byte)(0xff & (v >> 16));
		b[2] = (byte)(0xff & (v >>  8));
 		b[3] = (byte)(0xff & v);
 		return b;
	}

	public Object construct(byte[] b) {
		int v = (((b[0] & 0xff) << 24) |
				 ((b[1] & 0xff) << 16) |
				 ((b[2] & 0xff) <<  8) |
				 (b[3] & 0xff));
		return new Integer(v);
	}
}
